var group__PkgPolyhedronRef =
[
    [ "Concepts", "group__PkgPolyhedronConcepts.html", "group__PkgPolyhedronConcepts" ],
    [ "I/O Functions", "group__PkgPolyhedronIOFunc.html", "group__PkgPolyhedronIOFunc" ],
    [ "Draw a Polyhedron 3", "group__PkgDrawPolyhedron.html", "group__PkgDrawPolyhedron" ],
    [ "CGAL::Polyhedron_3< Traits >", "classCGAL_1_1Polyhedron__3.html", [
      [ "allocator_type", "classCGAL_1_1Polyhedron__3.html#add0588183a0e107bd7e2dc78909ca127", null ],
      [ "circulator_category", "classCGAL_1_1Polyhedron__3.html#a72c27f9439dcb1889505ecece9b4e206", null ],
      [ "difference_type", "classCGAL_1_1Polyhedron__3.html#abac442c83261a025d773fcf2a64cd953", null ],
      [ "Edge_iterator", "classCGAL_1_1Polyhedron__3.html#a260c899118aefbf92f85dcd72ce43851", null ],
      [ "Edges", "classCGAL_1_1Polyhedron__3.html#a1dfc0b86a7634374c1ec25f3bf6fbb2d", null ],
      [ "Facet_handle", "classCGAL_1_1Polyhedron__3.html#ad44731fbb60766ae1ea8e46b69d3cbbf", null ],
      [ "Facet_handles", "classCGAL_1_1Polyhedron__3.html#a53b1123a65846e5e61a6bb0fd29bf847", null ],
      [ "Facet_iterator", "classCGAL_1_1Polyhedron__3.html#a11883e7be5e610e823ebb46605e8772f", null ],
      [ "Halfedge_around_facet_circulator", "classCGAL_1_1Polyhedron__3.html#aaa493b9f4e392204345ecf79ebbd37e8", null ],
      [ "Halfedge_around_vertex_circulator", "classCGAL_1_1Polyhedron__3.html#a0bed29e3f406b13c8605f3f3e98d7175", null ],
      [ "Halfedge_handle", "classCGAL_1_1Polyhedron__3.html#a5ea0a8e088c2e98a6f1312d32f0a4967", null ],
      [ "Halfedge_handles", "classCGAL_1_1Polyhedron__3.html#a6659085c476499a617c39ef16f54e84e", null ],
      [ "Halfedge_iterator", "classCGAL_1_1Polyhedron__3.html#a6c11afde7bae6be0cc0006d0b2512a19", null ],
      [ "HalfedgeDS", "classCGAL_1_1Polyhedron__3.html#ab17a61da2a32f50b861cc261cd32c0bd", null ],
      [ "Items", "classCGAL_1_1Polyhedron__3.html#a82fc1b399742114ebc63c98405885e7b", null ],
      [ "iterator_category", "classCGAL_1_1Polyhedron__3.html#a7d6cdf0e8d7b13cb6d301987c1612b3c", null ],
      [ "Plane_3", "classCGAL_1_1Polyhedron__3.html#aa6d5d215f46423546681237d07a1e584", null ],
      [ "Plane_iterator", "classCGAL_1_1Polyhedron__3.html#af268be0ffff77469b60afbc4b4893ed5", null ],
      [ "Planes", "classCGAL_1_1Polyhedron__3.html#a746e4a0e5d32824f9bb001bdf254da13", null ],
      [ "Point_3", "classCGAL_1_1Polyhedron__3.html#a59bebced7ecd7660dd3ab1d33d22566f", null ],
      [ "Point_iterator", "classCGAL_1_1Polyhedron__3.html#a6aff2b5a8cb76cede147e32f500ad311", null ],
      [ "Points", "classCGAL_1_1Polyhedron__3.html#a11f504c4c3c7759eb0a5becb22c40ac1", null ],
      [ "size_type", "classCGAL_1_1Polyhedron__3.html#a859fcfdd3fa1df1ec6c2c98d10b85edb", null ],
      [ "Supports_facet_halfedge", "classCGAL_1_1Polyhedron__3.html#adb9c5380cb7d80196eff14e36c6a4ba1", null ],
      [ "Supports_facet_plane", "classCGAL_1_1Polyhedron__3.html#a1f2c8a28ffea579d07a50fcfcbd04e1c", null ],
      [ "Supports_halfedge_facet", "classCGAL_1_1Polyhedron__3.html#a04847ba8c46f51dacc38cff5640132e9", null ],
      [ "Supports_halfedge_prev", "classCGAL_1_1Polyhedron__3.html#a30a165f364597483f4ac1334642f4c51", null ],
      [ "Supports_halfedge_vertex", "classCGAL_1_1Polyhedron__3.html#a0acbd6f11423457c8cd0a194aa17eb1f", null ],
      [ "Supports_removal", "classCGAL_1_1Polyhedron__3.html#a1ea6e410d683cb382b1af84b85df70b9", null ],
      [ "Supports_vertex_halfedge", "classCGAL_1_1Polyhedron__3.html#ad575271460a9df1492e1f0f339f5bd31", null ],
      [ "Supports_vertex_point", "classCGAL_1_1Polyhedron__3.html#a62d1d69b081470716688036d66f4be7e", null ],
      [ "Vertex_handle", "classCGAL_1_1Polyhedron__3.html#aca51106e581d51d36bd668c819c0ac4e", null ],
      [ "Vertex_handles", "classCGAL_1_1Polyhedron__3.html#a675da64ded520fe6abca063ada3a1ed8", null ],
      [ "Vertex_iterator", "classCGAL_1_1Polyhedron__3.html#aff9ec9b39223e4f1cdf69ab39838e9e3", null ],
      [ "Polyhedron_3", "classCGAL_1_1Polyhedron__3.html#a58827beef13f3dd6b67f8337709bc501", null ],
      [ "Polyhedron_3", "classCGAL_1_1Polyhedron__3.html#a8bf0e9e52526da081375a7b49ca8b195", null ],
      [ "add_facet_to_border", "classCGAL_1_1Polyhedron__3.html#a73119c0c90bf8612da003305af25a52a", null ],
      [ "add_vertex_and_facet_to_border", "classCGAL_1_1Polyhedron__3.html#a684bc8315f9e97d59e10bf896f0a166c", null ],
      [ "border_edges_begin", "classCGAL_1_1Polyhedron__3.html#a4c3aeee01fe5fab394f364d5b117a21b", null ],
      [ "border_halfedges_begin", "classCGAL_1_1Polyhedron__3.html#acf8b79d9652f049ca360d805f73ba16f", null ],
      [ "bytes", "classCGAL_1_1Polyhedron__3.html#aa889170efd14f009004ab521606dc605", null ],
      [ "bytes_reserved", "classCGAL_1_1Polyhedron__3.html#a47000d54bd804fed1e4cc45c2dea122e", null ],
      [ "capacity_of_facets", "classCGAL_1_1Polyhedron__3.html#ac70e38b205cfcdbaa0a51d047f16e01d", null ],
      [ "capacity_of_halfedges", "classCGAL_1_1Polyhedron__3.html#a56711d646b29d468566e9e7371d36f93", null ],
      [ "capacity_of_vertices", "classCGAL_1_1Polyhedron__3.html#a5d999a50161f1353143e8d64e889ebc5", null ],
      [ "clear", "classCGAL_1_1Polyhedron__3.html#a87ed6b369ce8b0c6ad22f7a20dc6dbc9", null ],
      [ "create_center_vertex", "classCGAL_1_1Polyhedron__3.html#aca3b991cd6d926fd5b51b25766d36fad", null ],
      [ "delegate", "classCGAL_1_1Polyhedron__3.html#a7d5683b471d99bff3d73a467688151c5", null ],
      [ "edges", "classCGAL_1_1Polyhedron__3.html#a3c6662c06a8bb50b271fea179dd07fa3", null ],
      [ "edges_begin", "classCGAL_1_1Polyhedron__3.html#a251ab9cb55e77ad4ad6923914d5e65ea", null ],
      [ "edges_end", "classCGAL_1_1Polyhedron__3.html#a9ea95c5501c1af4d6a17b18c929c8faf", null ],
      [ "empty", "classCGAL_1_1Polyhedron__3.html#a8ce3e77931cf80fcda9c3c89564f1443", null ],
      [ "erase_center_vertex", "classCGAL_1_1Polyhedron__3.html#a2d08e7da8a337ed90b0db2e9a37d21c6", null ],
      [ "erase_connected_component", "classCGAL_1_1Polyhedron__3.html#a8497a896e1f23905c04accf99957afa1", null ],
      [ "erase_facet", "classCGAL_1_1Polyhedron__3.html#ac67041483c1e7c67c8dfd87716feebea", null ],
      [ "facet_handles", "classCGAL_1_1Polyhedron__3.html#a77a50500124207ecc42e8da2b47e0012", null ],
      [ "facets_begin", "classCGAL_1_1Polyhedron__3.html#a7bdcf3f2936fa9a27faf91536d953cba", null ],
      [ "facets_end", "classCGAL_1_1Polyhedron__3.html#ab34dd6ee47881cc822f578a9ba534f83", null ],
      [ "fill_hole", "classCGAL_1_1Polyhedron__3.html#ae05ca3c53d3ec0ce9e84c4b173b48e3e", null ],
      [ "flip_edge", "classCGAL_1_1Polyhedron__3.html#a633723d9b2f8a5972b8bfb4a4ea601ee", null ],
      [ "get_allocator", "classCGAL_1_1Polyhedron__3.html#ab741e3641ed4363ab156022525f82171", null ],
      [ "halfedge_handles", "classCGAL_1_1Polyhedron__3.html#aa5b19c47be114464b47a91bc60372c7c", null ],
      [ "halfedges_begin", "classCGAL_1_1Polyhedron__3.html#a8d38f95397f743187bdd389b2f83a3c4", null ],
      [ "halfedges_end", "classCGAL_1_1Polyhedron__3.html#abe1c7ae1fab1b3c7315b32d5d34ff2de", null ],
      [ "inside_out", "classCGAL_1_1Polyhedron__3.html#ac12b817b3d651cce74fbdaa711bacf33", null ],
      [ "is_closed", "classCGAL_1_1Polyhedron__3.html#a4afb025815064d4f125b8d3b0ba2b6f7", null ],
      [ "is_pure_bivalent", "classCGAL_1_1Polyhedron__3.html#a2415e1795ff4257b2080e60490124d3d", null ],
      [ "is_pure_quad", "classCGAL_1_1Polyhedron__3.html#affb9ffd609b66df43da8b3a7c352ccdc", null ],
      [ "is_pure_triangle", "classCGAL_1_1Polyhedron__3.html#a13ab704a6d26eb91c55cdb6828442ab1", null ],
      [ "is_pure_trivalent", "classCGAL_1_1Polyhedron__3.html#abb5fbc55c8a0e94ec9720fc951632ab0", null ],
      [ "is_tetrahedron", "classCGAL_1_1Polyhedron__3.html#af8993fad62cbddf613a26285bdb9fee8", null ],
      [ "is_triangle", "classCGAL_1_1Polyhedron__3.html#a0ff0a8c56eb8020fa517fca70b9b08d1", null ],
      [ "is_valid", "classCGAL_1_1Polyhedron__3.html#a3d67f3adbc2965b2ea54607d4f85ae89", null ],
      [ "join_facet", "classCGAL_1_1Polyhedron__3.html#a4f3e7c4e0800462026443a7ad0ca6db8", null ],
      [ "join_loop", "classCGAL_1_1Polyhedron__3.html#ad5a29fe94196629193da3c95e5eba5e9", null ],
      [ "join_vertex", "classCGAL_1_1Polyhedron__3.html#a8edb13d0fb5748b20a8173bec85e7243", null ],
      [ "keep_largest_connected_components", "classCGAL_1_1Polyhedron__3.html#a55f13c9c3dd5ab611d08dcd346d9190e", null ],
      [ "make_hole", "classCGAL_1_1Polyhedron__3.html#a228add3cae2d328bcdd67192a98fb636", null ],
      [ "make_tetrahedron", "classCGAL_1_1Polyhedron__3.html#a1ebc714bb6fc75a8aa105ffb241fe087", null ],
      [ "make_tetrahedron", "classCGAL_1_1Polyhedron__3.html#a19d554cc3a0e2db78b88d4e074c9fa19", null ],
      [ "make_triangle", "classCGAL_1_1Polyhedron__3.html#a06735e9d5caa84f0afb5ddab37a9dedf", null ],
      [ "make_triangle", "classCGAL_1_1Polyhedron__3.html#a62241505a5199ec963acd2a6fda4239f", null ],
      [ "normalize_border", "classCGAL_1_1Polyhedron__3.html#a6ca5eddcfe19c5b69a500f39a0bfdbe5", null ],
      [ "normalized_border_is_valid", "classCGAL_1_1Polyhedron__3.html#adb2db37bc2fcdd3e051260af9259f34e", null ],
      [ "planes", "classCGAL_1_1Polyhedron__3.html#aaf451356d666be3060567dd904bfb38f", null ],
      [ "planes_begin", "classCGAL_1_1Polyhedron__3.html#a409be107a687d3813b91f84a6e4459c9", null ],
      [ "planes_end", "classCGAL_1_1Polyhedron__3.html#abb6712371c2355442e42b6846bbc0375", null ],
      [ "points", "classCGAL_1_1Polyhedron__3.html#af6abde1634fdd64d79e78f07145186f2", null ],
      [ "points_begin", "classCGAL_1_1Polyhedron__3.html#a25d5ad0a16bbcf71ca1f48225b43bc95", null ],
      [ "points_end", "classCGAL_1_1Polyhedron__3.html#a45bf32fbaf7f185558e18194e4ab3830", null ],
      [ "reserve", "classCGAL_1_1Polyhedron__3.html#a545fadc0f4af7a1e4a1a0d1e26711f17", null ],
      [ "size_of_border_edges", "classCGAL_1_1Polyhedron__3.html#a1a1dbed72ce1b001446dd3ce25155d30", null ],
      [ "size_of_border_halfedges", "classCGAL_1_1Polyhedron__3.html#af156bdee96bbf065953569fe026795d9", null ],
      [ "size_of_facets", "classCGAL_1_1Polyhedron__3.html#a07c305cf6da9eeecc89fea2fc4f24f67", null ],
      [ "size_of_halfedges", "classCGAL_1_1Polyhedron__3.html#a022b5c320996fabb49673d8921437fcb", null ],
      [ "size_of_vertices", "classCGAL_1_1Polyhedron__3.html#ad661d362a8e515d67108803796eabac8", null ],
      [ "split_edge", "classCGAL_1_1Polyhedron__3.html#ab3269baf4b4c6ce61b86545b8fa360d2", null ],
      [ "split_facet", "classCGAL_1_1Polyhedron__3.html#a3ef41ae6c3be7f0894479f3dd4fe34d5", null ],
      [ "split_loop", "classCGAL_1_1Polyhedron__3.html#a375a1b49bc6ad2ad5c578d7a7c45e4f5", null ],
      [ "split_vertex", "classCGAL_1_1Polyhedron__3.html#a2b17d7bd2045397167b00616f3b4d622", null ],
      [ "traits", "classCGAL_1_1Polyhedron__3.html#a2eff5c59b448f9be755cb76cdf06d966", null ],
      [ "vertex_handles", "classCGAL_1_1Polyhedron__3.html#a2e0843aaeeadc428e8cd25802109bdf5", null ],
      [ "vertices_begin", "classCGAL_1_1Polyhedron__3.html#a94eec0aaf19925a005e5296d6c965c55", null ],
      [ "vertices_end", "classCGAL_1_1Polyhedron__3.html#aa402ee6ce24e0259a45c8579784a0f9a", null ],
      [ "operator<<", "group__PkgPolyhedronIOFunc.html#gae76f7723a658ce16b88063ee8a17805f", null ],
      [ "operator>>", "group__PkgPolyhedronIOFunc.html#gaf1ce25670b5796744cd6af0acce1562b", null ]
    ] ],
    [ "CGAL::Polyhedron_3< Traits >::Halfedge", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html", [
      [ "Facet", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a228e72adb988f1fb05f1dab4f91a98e9", null ],
      [ "Facet_const_handle", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a2e4ef338a6694d115759c97357bdf8ca", null ],
      [ "Facet_handle", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a733412bc21245b3f2b19a6e8eee24e0a", null ],
      [ "Halfedge_around_facet_circulator", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a3c54e1977b91dc462552b6c6a2aede7a", null ],
      [ "Halfedge_around_facet_const_circulator", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a085fd3d68cbb349d2bc64ea7250280c4", null ],
      [ "Halfedge_around_vertex_circulator", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a520b40a24cfac3bf7ccd6b9caafcfb2f", null ],
      [ "Halfedge_around_vertex_const_circulator", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a9f36d578254dc24749fdeb457c1f8f83", null ],
      [ "Halfedge_const_handle", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a4eccdbb5ce9d1ca63b76ac5fb12ab60e", null ],
      [ "Halfedge_handle", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a7dcf9fe71620e17fd74d61bbe0f480b3", null ],
      [ "Supports_halfedge_face", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a24b5416451096b02e24a8cefd9f2ec2d", null ],
      [ "Supports_halfedge_prev", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a05711761707dca54186c9c55119761bd", null ],
      [ "Supports_halfedge_vertex", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#ab3311964687efeb27951f253fdf36158", null ],
      [ "Vertex", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a200511a758fbfaa6ca4e79fe5c777d8c", null ],
      [ "Vertex_const_handle", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a65d24b19e42e678c51645021b022f9ad", null ],
      [ "Vertex_handle", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a41b85b5a28f69f4f8294b42ec4cddc1c", null ],
      [ "Halfedge", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a9c695b224baef8b7f37f71a5b1742967", null ],
      [ "facet", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a95ac2a25b518e5b5b7a374d4e0e4f3a3", null ],
      [ "facet", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a5b3a4964b535f466de9eb344af5ec108", null ],
      [ "facet_begin", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#ad7be4f01dbb682c48d41bee3c74315a4", null ],
      [ "facet_begin", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a300f3d7da0f06818cf413ce4d82737cc", null ],
      [ "facet_degree", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#abfe795ef209909dff2449458a968a82c", null ],
      [ "is_bivalent", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#abee693679bdbc170fb43b765e8c6c136", null ],
      [ "is_border", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#af8a71da247cf7e1cade77a64ff7693e6", null ],
      [ "is_border_edge", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a17e3fb1f48ef6045cbb45f0ed6cc4ec2", null ],
      [ "is_quad", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a865116b6dcce2106570dd0f9ea0da620", null ],
      [ "is_triangle", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a25e43495622b4f570a77f04d79539fc7", null ],
      [ "is_trivalent", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a7c5c3545abc863f1ebfc882c2dc3f9a1", null ],
      [ "next", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a3e7b0ca74b69a5868b430f958666df27", null ],
      [ "next", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a13c1ccf2f3619483c93e40cbe741b9d5", null ],
      [ "next_on_vertex", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a8ec76541f6bec85db65646e1d0d06e8e", null ],
      [ "next_on_vertex", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a6c4abd1441796e95c44d3f5d228d64e0", null ],
      [ "opposite", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a6f1d84341f035c8ed72ef53281173fb4", null ],
      [ "opposite", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a012bb26eca1acf4cf1513e08984c030e", null ],
      [ "prev", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a339a531b2c827bb2a15291ed04dc13cb", null ],
      [ "prev", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#ae733627c59ccfa1da672140f4af46c31", null ],
      [ "prev_on_vertex", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a51a86295bb2579f732018bb3a6871de6", null ],
      [ "prev_on_vertex", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#ae71070990b85ae6d1111531d066722f8", null ],
      [ "vertex", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a5d4131be8dac43edcb5f7376d2d125bd", null ],
      [ "vertex", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#af3b267ab42fb8798c4799e22d673f060", null ],
      [ "vertex_begin", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a334ad53a67472f005b01ff04c67fd918", null ],
      [ "vertex_begin", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a415291775befc854c2cce7ce786a8e7b", null ],
      [ "vertex_degree", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#ade6f857a843bbaad8db7c6149440806b", null ]
    ] ],
    [ "CGAL::Polyhedron_3< Traits >::Facet", "classCGAL_1_1Polyhedron__3_1_1Facet.html", [
      [ "Facet_const_handle", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a12108efd04c7db83ea7bf1c0b1ea6926", null ],
      [ "Facet_handle", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a6a810d0bf4dfaed87f96bcee2b6fd523", null ],
      [ "Halfedge", "classCGAL_1_1Polyhedron__3_1_1Facet.html#ae13016a6bb809b9037c0ed1e696b3c89", null ],
      [ "Halfedge_around_facet_circulator", "classCGAL_1_1Polyhedron__3_1_1Facet.html#af8ef93c699c1f35c6b1b9c9cddc91689", null ],
      [ "Halfedge_around_facet_const_circulator", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a6ed53a9b4af27d186fa9c306b6bd341a", null ],
      [ "Halfedge_const_handle", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a21258222601fd5c9828f1343f7d23c68", null ],
      [ "Halfedge_handle", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a03f7d1017366ad83bd94ab392811c063", null ],
      [ "Plane_3", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a159a10d39b86035154018f2bfdacfb75", null ],
      [ "Supports_facet_halfedge", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a9445ffcbaf964e7d2813eb1e9fda7b7c", null ],
      [ "Supports_facet_plane", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a8ad1c5b455bf34a885180e27af37ca1c", null ],
      [ "Vertex", "classCGAL_1_1Polyhedron__3_1_1Facet.html#af336272fdb47e7583f0fa115051eea25", null ],
      [ "Vertex_const_handle", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a563bd890d3a76e7cb1fe546db1ee7bc7", null ],
      [ "Vertex_handle", "classCGAL_1_1Polyhedron__3_1_1Facet.html#ae0b77c7a2fabee6f5d343c37c0fd6e4a", null ],
      [ "Facet", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a5ce0e814d298e5e1c6bc9ea91858c746", null ],
      [ "facet_begin", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a7e616a9768506bb444edea0ed44609d7", null ],
      [ "facet_begin", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a696b663a270861c5a20c651aa91ac45b", null ],
      [ "facet_degree", "classCGAL_1_1Polyhedron__3_1_1Facet.html#af73bbb2484025cf8678dce21f00eb391", null ],
      [ "halfedge", "classCGAL_1_1Polyhedron__3_1_1Facet.html#adeb2a50892d21dbc667fbe231f3b62b8", null ],
      [ "halfedge", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a65b2bda8760fb9a26c92bbfac040dbae", null ],
      [ "is_quad", "classCGAL_1_1Polyhedron__3_1_1Facet.html#aed46c7719365d6262c79b81777627ced", null ],
      [ "is_triangle", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a694040bb33e5068630756b8cd88963c5", null ],
      [ "plane", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a15efd739f38d8e4e1ce9f8274aa69672", null ],
      [ "plane", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a36c175db1be1c5bcbc982c227694fed9", null ],
      [ "set_halfedge", "classCGAL_1_1Polyhedron__3_1_1Facet.html#a64702da727fb51c2419b823d0b91ada6", null ]
    ] ],
    [ "CGAL::Polyhedron_3< Traits >::Vertex", "classCGAL_1_1Polyhedron__3_1_1Vertex.html", [
      [ "Facet", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#aab0c1a9a565f485307d54ab96e58a6d4", null ],
      [ "Facet_const_handle", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a957b6c2176991da4c30368ac22e45aaa", null ],
      [ "Facet_handle", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#adb6c48e6fb5d5810ef8ee9018830d004", null ],
      [ "Halfedge", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a7b3df3e4cc2210e7fd127ca1b9ddb191", null ],
      [ "Halfedge_around_vertex_circulator", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a5ef88ef4da0d869b4d8061d33958e651", null ],
      [ "Halfedge_around_vertex_const_circulator", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a2bf0edd40abdf1dc0c09c455374a8e7c", null ],
      [ "Halfedge_const_handle", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a7e715091093462c64141898ec05e9825", null ],
      [ "Halfedge_handle", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a813fa84a317fc9a3752229042e255171", null ],
      [ "Point_3", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a74b39a969a5e8ee9698aa986f00dc6b6", null ],
      [ "Supports_vertex_halfedge", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#af660c1187deebb1534e1ba2896baaa7a", null ],
      [ "Supports_vertex_point", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a9ff541fa0ab6d6b61e6adb026046b77b", null ],
      [ "Vertex_const_handle", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a4a065b3956d860b6bafd79a4c60d6e40", null ],
      [ "Vertex_handle", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a30b0d3a21da3da9db826cdc92bc17707", null ],
      [ "Vertex", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#acd24bfdd4bf0f9924e2c19ed75ace4af", null ],
      [ "Vertex", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a9212dbb357fa64131f7245444ecc5879", null ],
      [ "halfedge", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a11688de09f785f7d16ff3c10443fbab0", null ],
      [ "halfedge", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a08ed3cd95f800750867d9483d108575a", null ],
      [ "is_bivalent", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a38cf87f625b320b6b369802614699446", null ],
      [ "is_trivalent", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a12c86523fda1cce8e1b5a7d435cfb46b", null ],
      [ "point", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#ac49f332933bd0183b55057a6d1529cd1", null ],
      [ "point", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a64b4cee0e29cf17668258c4f2001026c", null ],
      [ "set_halfedge", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#adad072dfd8e0a22a72cc74c4fbd9face", null ],
      [ "vertex_begin", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a62f1d7a7581953fa024f7a52543e53a8", null ],
      [ "vertex_begin", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a8baec2e16ca5b627083caecc0097ce96", null ],
      [ "vertex_degree", "classCGAL_1_1Polyhedron__3_1_1Vertex.html#a7ec4abed5eb86ca93699b4cc316c811b", null ]
    ] ],
    [ "CGAL::Polyhedron_incremental_builder_3< HDS >", "classCGAL_1_1Polyhedron__incremental__builder__3.html", [
      [ "Facet_handle", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a606eee04fdd0e73fb9e571aba416e7a9", null ],
      [ "Halfedge_handle", "classCGAL_1_1Polyhedron__incremental__builder__3.html#ab3d834ff1dcadd23b55a4d1589ace457", null ],
      [ "HalfedgeDS", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a4d6b47abdda805ccc6142ecbe78002c7", null ],
      [ "Point_3", "classCGAL_1_1Polyhedron__incremental__builder__3.html#afba104cd587fb0f7a4ac4a43ea3e9f75", null ],
      [ "size_type", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a95d43a6f6f66bf12b17bada5d2a44ede", null ],
      [ "Vertex_handle", "classCGAL_1_1Polyhedron__incremental__builder__3.html#ab2b2fc2eaf5b797c0dcc277447ddb4be", null ],
      [ "Polyhedron_incremental_builder_3", "classCGAL_1_1Polyhedron__incremental__builder__3.html#acb8216ef40323e777f57cd4656d98c83", null ],
      [ "add_facet", "classCGAL_1_1Polyhedron__incremental__builder__3.html#ace001d4b34037e60f4c139c50c71799a", null ],
      [ "add_vertex", "classCGAL_1_1Polyhedron__incremental__builder__3.html#abc6f512872df9509a0393d9fcd4fa2e8", null ],
      [ "add_vertex_to_facet", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a2fdeee856c6746314d1c9c4851e404c5", null ],
      [ "begin_facet", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a36e32e762d26786afb8cbf3c4d4a9ebd", null ],
      [ "begin_surface", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a925a593ae76f78a4f41d7784bba91af6", null ],
      [ "check_unconnected_vertices", "classCGAL_1_1Polyhedron__incremental__builder__3.html#ae52dc79713a2008c7b864045222fe993", null ],
      [ "end_facet", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a24a3c6a73111e1171bb23b6e75f8ee73", null ],
      [ "end_surface", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a51c4d472aec12c4ad5d41e0695d91ead", null ],
      [ "error", "classCGAL_1_1Polyhedron__incremental__builder__3.html#ac59035edb88e2ad47085a6f4f6951581", null ],
      [ "remove_unconnected_vertices", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a69fdb0a788b8294a0de9f33edea26801", null ],
      [ "rollback", "classCGAL_1_1Polyhedron__incremental__builder__3.html#af5afb910f4ee79b8c0f37517aa338b3b", null ],
      [ "test_facet", "classCGAL_1_1Polyhedron__incremental__builder__3.html#a2b82ced26f21b4c297aba57792029860", null ],
      [ "vertex", "classCGAL_1_1Polyhedron__incremental__builder__3.html#acf2f65abeb4af0b40fe99abf55854d69", null ]
    ] ],
    [ "CGAL::Polyhedron_items_3", "classCGAL_1_1Polyhedron__items__3.html", [
      [ "Plane", "classCGAL_1_1Polyhedron__items__3.html#af54e6e98ef2970dba973e85425f06036", null ],
      [ "Supports_face_plane", "classCGAL_1_1Polyhedron__items__3.html#a1161cca4a567d1d25e50845bd84030b9", null ],
      [ "Polyhedron_items_3", "classCGAL_1_1Polyhedron__items__3.html#a07c95e555fbe70dba4639e761b745c7f", null ],
      [ "Point", "classCGAL_1_1Polyhedron__items__3.html#a226909e49108b48c946e5e3a27bbd19a", null ],
      [ "Supports_vertex_point", "classCGAL_1_1Polyhedron__items__3.html#a74f873d0af8a4b77bab6c1df3c91e6ac", null ]
    ] ],
    [ "CGAL::Polyhedron_min_items_3", "classCGAL_1_1Polyhedron__min__items__3.html", [
      [ "Supports_face_plane", "classCGAL_1_1Polyhedron__min__items__3.html#a83bbca2bb6db55b713cff99411de8cff", null ],
      [ "Polyhedron_min_items_3", "classCGAL_1_1Polyhedron__min__items__3.html#a8789e64309da299b6375fb7c400fbf8b", null ],
      [ "Point", "classCGAL_1_1Polyhedron__min__items__3.html#a2c13b2d7b5490561d1863e31202209be", null ],
      [ "Supports_vertex_point", "classCGAL_1_1Polyhedron__min__items__3.html#a7dc8bacaabc2175ad8fd8a69fbe9a2fd", null ]
    ] ],
    [ "CGAL::Polyhedron_traits_3< Kernel >", "classCGAL_1_1Polyhedron__traits__3.html", [
      [ "Construct_opposite_plane_3", "classCGAL_1_1Polyhedron__traits__3.html#a3c32c38bd9fc0b5a1880ed68512802f0", null ],
      [ "Kernel", "classCGAL_1_1Polyhedron__traits__3.html#a375be0eb3055107426e6f91982055aec", null ],
      [ "Plane_3", "classCGAL_1_1Polyhedron__traits__3.html#a099808dc96790e01331ac5323683b60a", null ],
      [ "Point_3", "classCGAL_1_1Polyhedron__traits__3.html#a55732819280265ce1af883d4d90d9aa0", null ],
      [ "Polyhedron_traits_3", "classCGAL_1_1Polyhedron__traits__3.html#ac303e0e08f64bc16be47d165104d1277", null ],
      [ "Polyhedron_traits_3", "classCGAL_1_1Polyhedron__traits__3.html#ad7fa6c0e191440e00365444901ad3876", null ],
      [ "construct_opposite_plane_3_object", "classCGAL_1_1Polyhedron__traits__3.html#af33c35e3cdb20bda5374f7a09ac0f734", null ]
    ] ],
    [ "CGAL::Polyhedron_traits_with_normals_3< Kernel >", "classCGAL_1_1Polyhedron__traits__with__normals__3.html", [
      [ "Construct_opposite_plane_3", "classCGAL_1_1Polyhedron__traits__with__normals__3.html#ae9d437809ba475201dd77f67ee328fd8", null ],
      [ "Kernel", "classCGAL_1_1Polyhedron__traits__with__normals__3.html#a7c12f76e10b5d3e96ea1ff7e1c5c8594", null ],
      [ "Plane_3", "classCGAL_1_1Polyhedron__traits__with__normals__3.html#a86ac05aa343644bb7e3db566de7c3a56", null ],
      [ "Point_3", "classCGAL_1_1Polyhedron__traits__with__normals__3.html#ade8f58b3ed1fda2abcd97ffeed238982", null ],
      [ "Polyhedron_traits_with_normals_3", "classCGAL_1_1Polyhedron__traits__with__normals__3.html#a2b8a80d6c7c3deeef4c4c277c4e3563d", null ],
      [ "Polyhedron_traits_with_normals_3", "classCGAL_1_1Polyhedron__traits__with__normals__3.html#a602e01dd6aa3c7952cf655a18f40d87a", null ],
      [ "construct_opposite_plane_3_object", "classCGAL_1_1Polyhedron__traits__with__normals__3.html#a358d953a6d810323edd444d8f245dd73", null ]
    ] ]
];